@@ -5,7 +5,7 @@ import numpy as np
 from torchvision import transforms
 
 from continuum.datasets import _ContinuumDataset
-from continuum.tasks import TaskSet
+from continuum.tasks import TaskSet, TaskType
 from continuum.transforms.segmentation import Compose as SegmentationCompose
 
 
@@ -31,10 +31,11 @@ class _BaseScenario(abc.ABC):
         self.cl_dataset = cl_dataset
         self._nb_tasks = nb_tasks
         self.transformations = transformations
+        self._counter = 0
 
         if transformations is None:
             self.transformations = self.cl_dataset.transformations
-        if self.cl_dataset.data_type == "segmentation":
+        if self.cl_dataset.data_type == TaskType.SEGMENTATION:
             composer = SegmentationCompose
         else:
             composer = transforms.Compose
@@ -57,6 +58,11 @@ class _BaseScenario(abc.ABC):
         """
         return self.cl_dataset.train
 
+    @property
+    def nb_samples(self) -> int:
+        """Total number of samples in the whole continual setting."""
+        return len(self.dataset[0])  # type: ignore
+
     @property
     def nb_classes(self) -> int:
         """Total number of classes in the whole continual setting."""
@@ -106,13 +112,14 @@ class _BaseScenario(abc.ABC):
                 "different set of transformations per task"
             )
 
-        x, y, t, _ = self._select_data_by_task(task_index)
+        x, y, t, _, data_indexes = self._select_data_by_task(task_index)
 
         return TaskSet(
             x, y, t,
             trsf=self.trsf[task_index] if isinstance(self.trsf, list) else self.trsf,
             data_type=self.cl_dataset.data_type,
-            bounding_boxes=self.cl_dataset.bounding_boxes
+            bounding_boxes=self.cl_dataset.bounding_boxes,
+            data_indexes=data_indexes
         )
 
     def _select_data_by_task(
@@ -123,7 +130,7 @@ class _BaseScenario(abc.ABC):
 
         This class returns the "task_index" in addition of the x, y, t data.
         This task index is either an integer or a list of integer when the user
-        used a slice. We need this variable when in segmentation to disangle
+        used a slice. We need this variable when in segmentation to disentangle
         samples with multiple task ids.
 
         :param task_index: The unique index of a task. As for List, you can use
@@ -132,7 +139,8 @@ class _BaseScenario(abc.ABC):
         :return: A tuple of numpy array being resp. (1) the data, (2) the targets,
                  (3) task ids, and (4) the actual task required by the user.
         """
-        x, y, t = self.dataset  # type: ignore
+
+        # conversion of task_index into a list
 
         if isinstance(task_index, slice):
             start = task_index.start if task_index.start is not None else 0
@@ -145,33 +153,40 @@ class _BaseScenario(abc.ABC):
         if isinstance(task_index, np.ndarray):
             task_index = list(task_index)
 
+        x, y, t = self.dataset  # type: ignore
+
         if isinstance(task_index, list):
             task_index = [
                 t if t >= 0 else _handle_negative_indexes(t, len(self)) for t in task_index
             ]
             if len(t.shape) == 2:
-                indexes = np.unique(np.where(t[:, task_index] == 1)[0])
+                data_indexes = np.unique(np.where(t[:, task_index] == 1)[0])
             else:
-                indexes = np.where(np.isin(t, task_index))[0]
+                data_indexes = np.where(np.isin(t, task_index))[0]
         else:
             if task_index < 0:
                 task_index = _handle_negative_indexes(task_index, len(self))
 
             if len(t.shape) == 2:
-                indexes = np.where(t[:, task_index] == 1)[0]
+                data_indexes = np.where(t[:, task_index] == 1)[0]
             else:
-                indexes = np.where(t == task_index)[0]
+                data_indexes = np.where(t == task_index)[0]
 
-        selected_x = x[indexes]
-        selected_y = y[indexes]
-        selected_t = t[indexes]
+        if self.cl_dataset.data_type == TaskType.H5:
+            # for h5 TaskType, x is just the filename containing all data
+            # no need for slicing here
+            selected_x = x
+        else:
+            selected_x = x[data_indexes]
+        selected_y = y[data_indexes]
+        selected_t = t[data_indexes]
 
         if self.cl_dataset.need_class_remapping:  # TODO: to remove with TransformIncremental
             # A remapping of the class ids is done to handle some special cases
             # like PermutedMNIST or RotatedMNIST.
             selected_y = self.cl_dataset.class_remapping(selected_y)
 
-        return selected_x, selected_y, selected_t, task_index
+        return selected_x, selected_y, selected_t, task_index, data_indexes
 
 
 def _handle_negative_indexes(index: int, total_len: int) -> int:
