@@ -5,7 +5,7 @@ from torchvision import transforms
 
 from continuum.datasets import _ContinuumDataset
 from continuum.scenarios import InstanceIncremental
-from continuum.tasks import TaskSet
+from continuum.tasks import TaskSet, TaskType
 
 
 class TransformationIncremental(InstanceIncremental):
@@ -33,6 +33,9 @@ class TransformationIncremental(InstanceIncremental):
         if incremental_transformations is None:
             raise ValueError("For this scenario a list transformation should be set")
 
+        if cl_dataset.data_type == TaskType.H5:
+            raise NotImplementedError("TransformationIncremental are not compatible yet with h5 files.")
+
         self.inc_trsf = incremental_transformations
         #self._nb_tasks = self._setup(nb_tasks)
         self.shared_label_space = shared_label_space
