@@ -1,6 +1,7 @@
 # pylint: disable=C0401
 # flake8: noqa
 from continuum.tasks.task_set import TaskSet
+from continuum.tasks.base import TaskType
 from continuum.tasks.utils import split_train_val, concat
 
-__all__ = ["TaskSet"]
+__all__ = ["TaskSet", "TaskType"]
